package org.mathcs.ibookmark;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;

import android.os.Bundle;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.view.ActionMode;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.AbsListView;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

public class BookmarkActivity extends Activity
{
	
	public final static String BOOKMARK_FILE_NAME = "bookmarks.txt";
	
	public final static String KEY_URL = "url";
	public final static String DEFAULT_URL = "http://www.shu.edu/";
	public final static int TEXT_SIZE = 18;
	public final static int TEXT_SIZE_SMALL = 16;

	
	private BookmarkAdapter data;
	private ListView list;
	
	@Override
	protected void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_bookmark);
	
		data = new BookmarkAdapter(this);
		list = (ListView)this.findViewById(R.id.id_list);
		list.setAdapter(data);
		
		list.setChoiceMode(ListView.CHOICE_MODE_MULTIPLE_MODAL);
		
		list.setOnItemClickListener(new AdapterView.OnItemClickListener()
			{
				@Override
				public void onItemClick(AdapterView<?> adapter, View view, int pos, long arg3)
				{
					startBookmark(pos);
				}
			});
		
		list.setMultiChoiceModeListener(new AbsListView.MultiChoiceModeListener()
				{

					@Override
					public boolean onActionItemClicked(ActionMode mode,
							MenuItem item)
					{
						// Respond to clicks on the actions in the CAB
						if (item.getItemId() == R.id.id_menu_del)
							deleteItems();
						else if (item.getItemId() == R.id.id_menu_edit)
							editItem();
						return false;
					}

					@Override
					public boolean onCreateActionMode(ActionMode mode, Menu menu)
					{
						// Inflate the menu for the CAB
						MenuInflater inflater = mode.getMenuInflater();
						inflater.inflate(R.menu.context, menu);
						return true;
					}

					@Override
					public void onDestroyActionMode(ActionMode mode)
					{
						// Here you can make any necessary updates to the activity when
						// the CAB is removed. By default, selected items are
						// deselected/unchecked.
						
					}

					@Override
					public boolean onPrepareActionMode(ActionMode mode,
							Menu menu)
					{
						// Here you can perform updates to the CAB due to
						// an invalidate() request
						return false;
					}

					@Override
					public void onItemCheckedStateChanged(ActionMode mode,
							int position, long id, boolean checked)
					{
						// Here you can do something when items are
						// selected/de-selected,
						// such as update the title in the CAB
						mode.setTitle(list.getCheckedItemCount() + " selcted");
					}
				});
		data.add(new Bookmark("Seton Hall Pirate", "http://pirate.shu.edu/"));
		data.add(new Bookmark("MathCS.org", "http://www.mathcs.org/"));
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.bookmark, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) 
	{
		if (item.getItemId() == R.id.id_menu_add)
		{
			addBookmark();
			return true;
		}
		else
			return super.onOptionsItemSelected(item);
	}
	
	@Override
	public void onPause()
	{
		super.onPause();
		Toast.makeText(this, "Saving", Toast.LENGTH_SHORT).show();
		save();
	}

	@Override
	public void onResume()
	{
		super.onResume();
		Toast.makeText(this, "Loading", Toast.LENGTH_SHORT).show();
		load();
	}
	
	private void addBookmark()
	{
		data.add(new Bookmark("Rutgers", "http://www.vrutgers.edu/"));
		data.notifyDataSetChanged();
	}
	
	private void startBookmark(int position)
	{
		Intent intent = new Intent(this, UrlViewer.class);
		intent.putExtra(KEY_URL, data.get(position).getUrl());
		
		startActivity(intent);
	}
	
	private void save()
	{
		try
		{
			PrintWriter out = new PrintWriter(
				new OutputStreamWriter(
					openFileOutput(BOOKMARK_FILE_NAME, Context.MODE_PRIVATE)));
			data.save(out);
			out.close();
		}
		catch(IOException ioe)
		{
			Toast.makeText(this, "Error saving data: " + ioe.getMessage(), Toast.LENGTH_SHORT).show();
		}
	}
	
	private void load()
	{
		try
		{
			BufferedReader in = new BufferedReader(
									new InputStreamReader(
										openFileInput(BOOKMARK_FILE_NAME)));
			data.load(in);
			in.close();
			data.notifyDataSetChanged();
		}
		catch(IOException ioe)
		{
			Toast.makeText(this, "Error loading data: " + ioe.getMessage(), Toast.LENGTH_SHORT).show();
		}
	}
	

	protected void editItem()
	{
		Toast.makeText(this, "Editiing ...", Toast.LENGTH_SHORT).show();
		
	}

	protected void deleteItems()
	{
		// TODO Auto-generated method stub
		Toast.makeText(this, "Deleting ....", Toast.LENGTH_SHORT).show();
	}

}
